==> apache-VCL-2.5.tar.bz2: apache-VCL-2.5/web/js/nls/pt_PT/messages.js <==
/*
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements.  See the NOTICE file distributed with
* this work for additional information regarding copyright ownership.
* The ASF licenses this file to You under the Apache License, Version 2.0
* (the "License"); you may not use this file except in compliance with
* the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

nlsmessages = {
'Create / Update an Image':'Criar / Atualizar uma Imagem',
'You do not have access to create or update any images.':'Você não tem acesso para criar ou atualizar nenhuma imagem.',
'(New Profile)':'(Novo Perfil)',
'The start day and time must be in the future.':'O dia de inicio e o tempo tem que ser no futuro.',
'The end time must be at least 30 minutes in the future.':'O tempo de fim tem que ser pelo menos 30 minutos no futuro.',
'The end time must be after the start time.':'O tempo de fim tem que ser a seguir o tempo de inicio.',
'The end time is too close to the start time.':'O tempo de fim é muito próximo do tempo de inicio.',
'The submitted start time is in the past.':'A data de arranque submetida é no passado.',
'Times cannot be suggested for cluster reservations':'Os tempos não podem ser sugeridos pela reserva de cluster',
'Cancel':'Cancelar',
'Okay':'OK',
'Create Reservation':'Criar Reserva',
'Modify Reservation':'Modificar Reserva',
'Create Imaging Reservation':"Criar Reserva de Imagem",
'Deploy Server':"Colocar Servidor em Produção",
'Please select a valid environment.':'Por favor escolha um ambiente válido.',
'View Available Times':'Ver Tempos Disponíveis',
'hour':'hora',
'weeks':'',
'days':'dias',
'hours':'horas',
'There are multiple versions of this environment available.':"Há disponível múltiplas versões deste ambiente.",
'Please select the version you would like to check out:':"Por favor escolha a versão que você gostaria de disponibilizar:",
'Select Image Revisions':'Escolha Revisões de Imagem',
'Revision':'Revisão',
'User':'Utilizador',
'Created':'Criado',
'Production':'Produção',
'Working...':'Trabalhando...',
'Loading...':'Carregando...',
'The end time must be later than the start time.':"O tempo de fim tem que ser mais tarde que o tempo de inicio.",
'The reservation you selected<br>to edit has expired.<br><br>':'A reserva escolhida por si<br>para alterar expirou.<br><br>',
'The reservation you selected<br>to reboot has expired.<br><br>':'A reserva escolhida por si<br>para rearrancar expirou.<br><br>',
'The reservation you selected<br>to reinstall has expired.<br><br>':'A reserva escolhida por si<br>para reinstalar expirou.<br><br>',
'An invalid version was submitted.':'Uma versão inválidafoi submetida.',
'(No description)':'(Não há descrição)',
'You do not have access to apply this server profile.':'Você não tem acesso para aplicar este perfil de servidor.',
'Delete':'Apagar',
'Undelete':'Recuperar',
'Edit':'Alterar',
'You do not have access to the submitted resource or group':'Você não tem acesso a este recurso ou grupo submetido',
'Resource In Use':'Recurso em Utilização',
'Problem encountered while attempting to delete resource. Please contact a system administrator.':'Problema encontrado enquanto se tentava apagar recurso. Por favor contact o administrador de sistema.',
'Unmatched or empty brackets ( [ and ] ) in subject':'',
'Unmatched or empty brackets ( [ and ] ) in message':'',
'Unmatched or empty brackets ( [ and ] ) in short message':'',
'false':'falso',
'true':'verdadeiro',
'Save Changes':'Gravar Alterações',
'Access denied to edit this item':'Acesso negado para alterar este item',
'Invalid network speed specified':'Velocidade de rede especificada inválida',
'Max Concurrent Usage must be between 0 and 255':'Máximo de Utilização Concorrente tem que ser entre 0 e 255',
'Invalid value specified for \'Available for checkout\'':'Valor especificado inválido para \'Disponível para checkout\'',
'Invalid value specified for \'Check for logged in user\'':'Valor especificado inválido para \'Verificar se o utilizador está no sistema\'',
'Invalid value specified for \'Users have administrative access\'':'Valor especificado inválido para \'Utilizadores com acesso administrativo\'',
'Invalid value specified for \'Set computer hostname\'':'Valor especificado inválido para \'Definir o nome do computador\'',
'Invalid value specified for \'Use sysprep\'':'Valor especificado inválido para \'Utilizar o sysprep\'',
'Invalid Connect Methods specified':'Forma de conexão especificada inválida',
'Add Subimage':'Acrescentar Subimagem',
'(None)':'(Nada)',
'Remove Selected Subimage(s)':'Retirar Subimagem(ens) Escolhidas',
'Add Method':'Acrescentar Forma',
'There must be at least one item in Current Methods':'Tem que haver pelo menos um item nas Formas Correntes',
'Remove Selected Methods':'Retirar Formas Escolhidas',
'You cannot delete the production revision.':'Você não pode apagar a revisão de produção.',
'Create Image':'Criar Imagem',
'You must be the owner of the image to update it.':'Você tem que ser o dono da imagem para poder atualizá-la.',
'Remove':"Retirar",
'The selected Block Request no longer exists.':'O bloco requisitado escolhido já não existe.',
'These times overlap with an existing time slot':'Este horário sobrepõem-se a um horário já existente',
'The date must be today or later':'A data tem que ser hoje ou mais tarde',
'The date and times overlap with an existing time slot':'A data e horário sobrepõem-se com um horário já existente',
'Please fix invalid values before submitting.':'Por favor corrija os valores inválidos antes fazer a submissão.',
'Please fill in First Date of Usage':'Por favor preencha na Primeira Data de Utilização',
'Please fill in Last Date of Usage':'Por favor preencha na Última Data de Utilização',
'The First Date of Usage must be today or later':'A Primeira Data de Utilização tem que ser hoje ou mais tarde',
'The Last Date of Usage must be the same or later than the First Date of Usage':'A Última Data de Utilização tem que ser igual ou mais tarde do que a Primeira Data de Utilização',
'The Last Date of Usage must be today or later':'A Última Data de Utilização tem que ser hoje ou mais tarde',
'Sunday':'Domingo',
'Monday':'Segunda',
'Tuesday':'Terça',
'Wednesday':'Quarta',
'Thursday':'Quinta',
'Friday':'Sexta',
'Saturday':'Sábado',
'At least one day must be checked when using "Repeating Weekly"':'Pelo menos um dia tem que ser marcado quando se usa "Repetindo Semanalmente"',
'At least one start/end combination must be entered when using "Repeating Weekly"':'Pelo menos uma combinação de inicio/fim tem que ser colocada quando se usa "Repetindo Semanalmente"',
'When submitting "(group not listed)" as the user group, information must be included in the comments about what group needs to be created.':'Quando submeter "(grupo não listado)" como o grupo de utilizador, a informação tem que ser incluída nos comentários acerca do que o grupo necessita para ser criado.',
'Name:':'Nome:',
'Owner:':'Dono:',
'specified in comments':'especificado nos comentários',
'Weekly':'Semanalmente',
'First Date:':'Primeira Data:',
'Last Date:':'Última Data:',
'Repeating on these days:':'Repetindo nestes dias:',
'During these times:':'Durante estes horários:',
'At least one start/end combination must be entered when using "Repeating Monthly"':'Pelo menos uma combinação de inicio/fim tem que ser colocada quando se usa "Repetindo Mensalmente"',
'Monthly':'Mensal',
'Repeat on:':'Repetir em:',
'of each month':"de cada mês",
'At least one date/start/end combination must be entered when using "List of Dates/Times"':'Pelo menos uma combinação de data/inicio/fim tem que ser colocada quando se usa "Lista de Datas/Horários"',
'List of Dates/Times':'Lista de Datas/Horários',
'User Submitted Comments:':'Comentários Submetidos do Utilizador:',
'Skip':'Avançar',
'Use':'Uso',
'Total online:':'Total online',
'match':'coincide',
'no match':'não coincide',
'Error encountered:':'Erro encontrado',
'Please try again later':'Por favor tente novamente mais tarde',
'Values updated':'',
'Submit Changes':'',
'Add':'',
'Invalid item selected for new value':'',
'Invalid value submitted':'',
'Invalid item submitted for deletion':'',
'You do not have access to modify the submitted settings.':'',
'Invalid value submitted for ':'',
'NFS Mounts':'',
'NFS Mounts are NFS exports that are to be mounted within each reservation deployed by a given management node.<br>Values must be like':'',
'Invalid value - must be in the form':'',
'Messages':'',
'This section allows for configuration of messages that are sent to users and administrators about things such as reservations and image management. Every message has a default. Additionally, separate messages can be configured for each affiliation. Most of the messages will have parts that are in square brackets. These parts will have data substituted for them before the message is sent. A list of what can be used in squeare brackets can be found at the <a href=\"%s\">Apache VCL web site</a>. Some messages also have a short form that may be sent such as in the form of a popup within a reservation when the reservation is about to end.':'',
'Save Message':'',
'Delete Message and Use Default':'',
'The following messages have invalid items included for substitution. Please correct the message contents and save them again for the backend to validate.':'',
'Message type %s for affiliation %s successfully deleted':'',
'Invalid item submitted to save':'',
'Message successfully saved':'',
'No changes to submitted message. Nothing saved.':'',
'unset':''
}

==> apache-VCL-2.5.1.tar.bz2: apache-VCL-2.5.1/web/js/nls/pt_PT/messages.js <==
/*
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements.  See the NOTICE file distributed with
* this work for additional information regarding copyright ownership.
* The ASF licenses this file to You under the Apache License, Version 2.0
* (the "License"); you may not use this file except in compliance with
* the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

nlsmessages = {
'Create / Update an Image':'Criar / Atualizar uma Imagem',
'You do not have access to create or update any images.':'Você não tem acesso para criar ou atualizar nenhuma imagem.',
'(New Profile)':'(Novo Perfil)',
'The start day and time must be in the future.':'O dia de inicio e o tempo tem que ser no futuro.',
'The end time must be at least 30 minutes in the future.':'O tempo de fim tem que ser pelo menos 30 minutos no futuro.',
'The end time must be after the start time.':'O tempo de fim tem que ser a seguir o tempo de inicio.',
'The end time is too close to the start time.':'O tempo de fim é muito próximo do tempo de inicio.',
'The submitted start time is in the past.':'A data de arranque submetida é no passado.',
'Times cannot be suggested for cluster reservations':'Os tempos não podem ser sugeridos pela reserva de cluster',
'Cancel':'Cancelar',
'Okay':'OK',
'Create Reservation':'Criar Reserva',
'Modify Reservation':'Modificar Reserva',
'Create Imaging Reservation':"Criar Reserva de Imagem",
'Deploy Server':"Colocar Servidor em Produção",
'Please select a valid environment.':'Por favor escolha um ambiente válido.',
'View Available Times':'Ver Tempos Disponíveis',
'hour':'hora',
'weeks':'',
'days':'dias',
'hours':'horas',
'There are multiple versions of this environment available.':"Há disponível múltiplas versões deste ambiente.",
'Please select the version you would like to check out:':"Por favor escolha a versão que você gostaria de disponibilizar:",
'Select Image Revisions':'Escolha Revisões de Imagem',
'Revision':'Revisão',
'User':'Utilizador',
'Created':'Criado',
'Production':'Produção',
'Working...':'Trabalhando...',
'Loading...':'Carregando...',
'The end time must be later than the start time.':"O tempo de fim tem que ser mais tarde que o tempo de inicio.",
'The reservation you selected<br>to edit has expired.<br><br>':'A reserva escolhida por si<br>para alterar expirou.<br><br>',
'The reservation you selected<br>to reboot has expired.<br><br>':'A reserva escolhida por si<br>para rearrancar expirou.<br><br>',
'The reservation you selected<br>to reinstall has expired.<br><br>':'A reserva escolhida por si<br>para reinstalar expirou.<br><br>',
'An invalid version was submitted.':'Uma versão inválidafoi submetida.',
'(No description)':'(Não há descrição)',
'You do not have access to apply this server profile.':'Você não tem acesso para aplicar este perfil de servidor.',
'Delete':'Apagar',
'Undelete':'Recuperar',
'Edit':'Alterar',
'You do not have access to the submitted resource or group':'Você não tem acesso a este recurso ou grupo submetido',
'Resource In Use':'Recurso em Utilização',
'Problem encountered while attempting to delete resource. Please contact a system administrator.':'Problema encontrado enquanto se tentava apagar recurso. Por favor contact o administrador de sistema.',
'Unmatched or empty brackets ( [ and ] ) in subject':'',
'Unmatched or empty brackets ( [ and ] ) in message':'',
'Unmatched or empty brackets ( [ and ] ) in short message':'',
'false':'falso',
'true':'verdadeiro',
'Save Changes':'Gravar Alterações',
'Access denied to edit this item':'Acesso negado para alterar este item',
'Invalid network speed specified':'Velocidade de rede especificada inválida',
'Max Concurrent Usage must be between 0 and 255':'Máximo de Utilização Concorrente tem que ser entre 0 e 255',
'Invalid value specified for \'Available for checkout\'':'Valor especificado inválido para \'Disponível para checkout\'',
'Invalid value specified for \'Check for logged in user\'':'Valor especificado inválido para \'Verificar se o utilizador está no sistema\'',
'Invalid value specified for \'Users have administrative access\'':'Valor especificado inválido para \'Utilizadores com acesso administrativo\'',
'Invalid value specified for \'Set computer hostname\'':'Valor especificado inválido para \'Definir o nome do computador\'',
'Invalid value specified for \'Use sysprep\'':'Valor especificado inválido para \'Utilizar o sysprep\'',
'Invalid Connect Methods specified':'Forma de conexão especificada inválida',
'Add Subimage':'Acrescentar Subimagem',
'(None)':'(Nada)',
'Remove Selected Subimage(s)':'Retirar Subimagem(ens) Escolhidas',
'Add Method':'Acrescentar Forma',
'There must be at least one item in Current Methods':'Tem que haver pelo menos um item nas Formas Correntes',
'Remove Selected Methods':'Retirar Formas Escolhidas',
'You cannot delete the production revision.':'Você não pode apagar a revisão de produção.',
'Create Image':'Criar Imagem',
'You must be the owner of the image to update it.':'Você tem que ser o dono da imagem para poder atualizá-la.',
'Remove':"Retirar",
'The selected Block Request no longer exists.':'O bloco requisitado escolhido já não existe.',
'These times overlap with an existing time slot':'Este horário sobrepõem-se a um horário já existente',
'The date must be today or later':'A data tem que ser hoje ou mais tarde',
'The date and times overlap with an existing time slot':'A data e horário sobrepõem-se com um horário já existente',
'Please fix invalid values before submitting.':'Por favor corrija os valores inválidos antes fazer a submissão.',
'Please fill in First Date of Usage':'Por favor preencha na Primeira Data de Utilização',
'Please fill in Last Date of Usage':'Por favor preencha na Última Data de Utilização',
'The First Date of Usage must be today or later':'A Primeira Data de Utilização tem que ser hoje ou mais tarde',
'The Last Date of Usage must be the same or later than the First Date of Usage':'A Última Data de Utilização tem que ser igual ou mais tarde do que a Primeira Data de Utilização',
'The Last Date of Usage must be today or later':'A Última Data de Utilização tem que ser hoje ou mais tarde',
'Sunday':'Domingo',
'Monday':'Segunda',
'Tuesday':'Terça',
'Wednesday':'Quarta',
'Thursday':'Quinta',
'Friday':'Sexta',
'Saturday':'Sábado',
'At least one day must be checked when using "Repeating Weekly"':'Pelo menos um dia tem que ser marcado quando se usa "Repetindo Semanalmente"',
'At least one start/end combination must be entered when using "Repeating Weekly"':'Pelo menos uma combinação de inicio/fim tem que ser colocada quando se usa "Repetindo Semanalmente"',
'When submitting "(group not listed)" as the user group, information must be included in the comments about what group needs to be created.':'Quando submeter "(grupo não listado)" como o grupo de utilizador, a informação tem que ser incluída nos comentários acerca do que o grupo necessita para ser criado.',
'Name:':'Nome:',
'Owner:':'Dono:',
'specified in comments':'especificado nos comentários',
'Weekly':'Semanalmente',
'First Date:':'Primeira Data:',
'Last Date:':'Última Data:',
'Repeating on these days:':'Repetindo nestes dias:',
'During these times:':'Durante estes horários:',
'At least one start/end combination must be entered when using "Repeating Monthly"':'Pelo menos uma combinação de inicio/fim tem que ser colocada quando se usa "Repetindo Mensalmente"',
'Monthly':'Mensal',
'Repeat on:':'Repetir em:',
'of each month':"de cada mês",
'At least one date/start/end combination must be entered when using "List of Dates/Times"':'Pelo menos uma combinação de data/inicio/fim tem que ser colocada quando se usa "Lista de Datas/Horários"',
'List of Dates/Times':'Lista de Datas/Horários',
'User Submitted Comments:':'Comentários Submetidos do Utilizador:',
'Skip':'Avançar',
'Use':'Uso',
'Total online:':'Total online',
'match':'coincide',
'no match':'não coincide',
'Error encountered:':'Erro encontrado',
'Please try again later':'Por favor tente novamente mais tarde',
'Values updated':'',
'Submit Changes':'',
'Add':'',
'Invalid item selected for new value':'',
'Invalid value submitted':'',
'Invalid item submitted for deletion':'',
'You do not have access to modify the submitted settings.':'',
'Invalid value submitted for ':'',
'NFS Mounts':'',
'NFS Mounts are NFS exports that are to be mounted within each reservation deployed by a given management node.<br>Values must be like':'',
'Invalid value - must be in the form':'',
'Messages':'',
'This section allows for configuration of messages that are sent to users and administrators about things such as reservations and image management. Every message has a default. Additionally, separate messages can be configured for each affiliation. Most of the messages will have parts that are in square brackets. These parts will have data substituted for them before the message is sent. A list of what can be used in squeare brackets can be found at the <a href=\"%s\">Apache VCL web site</a>. Some messages also have a short form that may be sent such as in the form of a popup within a reservation when the reservation is about to end.':'',
'Save Message':'',
'Delete Message and Use Default':'',
'The following messages have invalid items included for substitution. Please correct the message contents and save them again for the backend to validate.':'',
'Message type %s for affiliation %s successfully deleted':'',
'Invalid item submitted to save':'',
'Message successfully saved':'',
'No changes to submitted message. Nothing saved.':'',
'unset':'',
'1 hour':'',
'Default for User':'',
'Invalid Max Reservation Duration selected':'',
'minutes':'',
'Passwords do not match':''
}
